# saxo

Quick and flexible [irc bot](https://en.wikipedia.org/wiki/Internet_Relay_Chat_bot), extensible in any language.

## Quick start

You will need [Python](http://www.python.org/) 3.3 or later.

    git clone https://github.com/sbp/saxo.git
    cd saxo
    ./saxo create

Edit your `~/.saxo/config` file in a text editor. Then start the bot:

    ./saxo -f start

## License

To be decided. Will be a [FLOSS](https://en.wikipedia.org/wiki/Free_and_open-source_software#FLOSS) license.
